@@ -24,10 +24,6 @@
 #include <locale.h>
 #endif
 
-#ifdef HAVE_UNIQUE
-#include <unique/unique.h>
-#endif
-
 #include <glib/gstdio.h>
 #include <gtk/gtk.h>
 #include <libxfce4ui/libxfce4ui.h>
@@ -77,11 +73,7 @@ prop_dialog_run (void)
   GtkWidget *action_dialog;
   GtkWidget *combobox;
 
-  builder = gtk_builder_new ();
-  gtk_builder_add_from_string (builder, settings_dialog_ui, settings_dialog_ui_length, NULL);
-
   /* Dialogs */
-  settings_dialog = GTK_WIDGET (gtk_builder_get_object (builder, "settings-dialog"));
   action_dialog = GTK_WIDGET (gtk_builder_get_object (builder, "action-dialog"));
 
   /* General settings */
@@ -118,7 +110,7 @@ prop_dialog_run (void)
                           gtk_builder_get_object (builder, "max-texts-in-history"), "value");
 
   /* Actions tab and dialog */
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder, "enable-actions")),
+  gtk_switch_set_state (GTK_SWITCH (gtk_builder_get_object (builder, "enable-actions")),
                                 DEFAULT_ENABLE_ACTIONS);
   xfconf_g_property_bind (xfconf_channel, "/settings/enable-actions", G_TYPE_BOOLEAN,
                           gtk_builder_get_object (builder, "enable-actions"), "active");
@@ -189,25 +181,11 @@ prop_dialog_run (void)
 
   /* Tweaks tab: paste-on-activate combobox */
   combobox = GTK_WIDGET (gtk_builder_get_object (builder, "combobox-paste-on-activate"));
-
-  {
-    GtkListStore *store;
-    GtkCellRenderer *cell;
-
-    store = gtk_list_store_new (1, G_TYPE_STRING);
-    gtk_combo_box_set_model (GTK_COMBO_BOX (combobox), GTK_TREE_MODEL (store));
-    g_object_unref (store);
-
-    cell = gtk_cell_renderer_text_new ();
-    gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combobox), cell, TRUE);
-    gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combobox), cell, "text", 0, NULL);
-  }
-
-  gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("None"));
+  gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combobox), _("None"));
   /* TRANSLATORS: Keyboard shortcut */
-  gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("Ctrl+V"));
+  gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combobox), _("Ctrl+V"));
   /* TRANSLATORS: Keyboard shortcut */
-  gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("Shift+Insert"));
+  gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combobox), _("Shift+Insert"));
   gtk_combo_box_set_active (GTK_COMBO_BOX (combobox), 0);
 
   xfconf_g_property_bind (xfconf_channel, "/tweaks/paste-on-activate",
@@ -231,7 +209,7 @@ cb_show_help (GtkButton *button)
   gchar *offset;
   gchar *docpath = NULL;
   gchar *command = NULL;
-  
+
   /* Find localized documentation path on disk */
 #ifdef ENABLE_NLS
 #ifdef HAVE_LOCALE_H
@@ -750,12 +728,12 @@ cb_test_regex (GtkButton *button)
   gtk_widget_hide (dialog);
 }
 
-static void 
+static void
 cb_test_regex_changed (GtkWidget *widget)
 {
   if (test_regex_changed_timeout == 0)
-    gtk_entry_set_icon_from_stock (GTK_ENTRY (gtk_builder_get_object (builder, "regex-entry")),
-                                   GTK_ENTRY_ICON_SECONDARY, GTK_STOCK_REFRESH);
+    gtk_entry_set_icon_from_icon_name (GTK_ENTRY (gtk_builder_get_object (builder, "regex-entry")),
+                                   GTK_ENTRY_ICON_SECONDARY, "gtk-refresh");
 
   if (test_regex_changed_timeout > 0)
     g_source_remove (test_regex_changed_timeout);
@@ -797,10 +775,10 @@ update_test_regex_textview_tags (void)
   regex = g_regex_new (pattern, G_REGEX_CASELESS|G_REGEX_MULTILINE, 0, NULL);
   if (regex == NULL)
     {
-      gtk_entry_set_icon_from_stock (GTK_ENTRY (entry), GTK_ENTRY_ICON_SECONDARY, GTK_STOCK_DIALOG_ERROR);
+      gtk_entry_set_icon_from_icon_name (GTK_ENTRY (entry), GTK_ENTRY_ICON_SECONDARY, "dialog-error");
       return;
     }
-  gtk_entry_set_icon_from_stock (GTK_ENTRY (entry), GTK_ENTRY_ICON_SECONDARY, GTK_STOCK_APPLY);
+  gtk_entry_set_icon_from_icon_name (GTK_ENTRY (entry), GTK_ENTRY_ICON_SECONDARY, "dialog-apply");
 
   text = gtk_text_buffer_get_text (buffer, &start, &end, FALSE);
   if (!g_regex_match (regex, text, 0, &match_info))
@@ -877,47 +855,41 @@ cb_set_action_dialog_button_ok (GtkWidget *widget)
 
 
 
-/* Main */
-#ifdef HAVE_UNIQUE
-static UniqueResponse
-cb_unique_app (UniqueApp *app,
-               gint command,
-               UniqueMessageData *message_data,
-               guint time_,
-               gpointer user_data)
-{
-  if (command != UNIQUE_ACTIVATE)
-    {
-      return UNIQUE_RESPONSE_PASSTHROUGH;
-    }
-
-  gtk_window_present (GTK_WINDOW (settings_dialog));
-  return UNIQUE_RESPONSE_OK;
-}
-#endif
-
 gint
 main (gint argc,
       gchar *argv[])
 {
+  GtkApplication *app;
+  GError *error = NULL;
+
   xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, NULL);
   xfconf_init (NULL);
   gtk_init (&argc, &argv);
 
-#ifdef HAVE_UNIQUE
-    {
-      UniqueApp *app = unique_app_new ("org.xfce.Clipman", NULL);
-      if (unique_app_is_running (app))
-        {
-          if (unique_app_send_message (app, UNIQUE_ACTIVATE, NULL) == UNIQUE_RESPONSE_OK)
-            {
-              g_object_unref (app);
-              return 0;
-            }
-        }
-      g_signal_connect (app, "message-received", G_CALLBACK (cb_unique_app), NULL);
-    }
-#endif
+  app = gtk_application_new ("org.xfce.Clipman", G_APPLICATION_FLAGS_NONE);
+
+  g_application_register (G_APPLICATION (app), NULL, &error);
+  if (error != NULL)
+  {
+    g_warning ("Unable to register GApplication: %s", error->message);
+    g_clear_error (&error);
+    return 1;
+  }
+
+  if (g_application_get_is_remote (G_APPLICATION (app)))
+  {
+    g_application_activate (G_APPLICATION (app));
+    g_object_unref (app);
+    return 0;
+  }
+
+  builder = gtk_builder_new ();
+  gtk_builder_add_from_string (builder, settings_dialog_ui, settings_dialog_ui_length, NULL);
+
+  /* Main Dialog */
+  settings_dialog = GTK_WIDGET (gtk_builder_get_object (builder, "settings-dialog"));
+
+  g_signal_connect_swapped (app, "activate", G_CALLBACK (gtk_window_present), settings_dialog);
 
   xfconf_channel = xfconf_channel_new_with_property_base ("xfce4-panel", "/plugins/clipman");
   actions = clipman_actions_get ();
